# Copyright (C) 2020 by ÿnérant, eichhornchen, nicomarg, charlse
# SPDX-License-Identifier: GPL-3.0-or-later

import curses

from ..entities.player import Player
from ..game import Game
from ..translations import gettext as _
from .display import Display


class StatsDisplay(Display):
    """
    A class to handle the display of the stats of the player.
    """
    player: Player

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.pad = self.newpad(self.rows, self.cols)

    def update(self, game: Game) -> None:
        self.player = game.player

    def update_pad(self) -> None:
        string2 = "Player -- LVL {}\nEXP {}/{}\nHP {}/{}"\
            .format(self.player.level, self.player.current_xp,
                    self.player.max_xp, self.player.health,
                    self.player.maxhealth)
        self.addstr(self.pad, 0, 0, string2)
        string3 = "STR {}\nINT {}\nCHR {}\nDEX {}\nCON {}"\
            .format(self.player.strength,
                    self.player.intelligence, self.player.charisma,
                    self.player.dexterity, self.player.constitution)
        self.addstr(self.pad, 3, 0, string3)

        inventory_str = _("Inventory:") + " "
        # Stack items by type instead of displaying each item
        item_types = [item.name for item in self.player.inventory]
        item_types.sort(key=item_types.count, reverse=True)
        printed_items = []
        for item in item_types:
            if item in printed_items:
                continue
            count = item_types.count(item)
            inventory_str += self.pack[item.upper()]
            if count > 1:
                inventory_str += f"x{count} "
            printed_items.append(item)
        self.addstr(self.pad, 8, 0, inventory_str)

        self.addstr(self.pad, 9, 0, f"{self.pack.HAZELNUT} "
                                    f"x{self.player.hazel}")

        if self.player.dead:
            self.addstr(self.pad, 11, 0, _("YOU ARE DEAD"), curses.COLOR_RED,
                        bold=True, blink=True, standout=True)

    def display(self) -> None:
        self.pad.erase()
        self.update_pad()
        self.refresh_pad(self.pad, 0, 0, self.y, self.x,
                         self.y + self.height - 1, self.width + self.x - 1)
